#[non_exhaustive]pub struct RemoteNetworkProxyLaunchConfig {
pub proxy: RemoteNetworkProxyConfig,
pub audit_metadata: NetworkProxyAuditMetadata,
pub environment_id: Option<String>,
pub execution_id: Option<String>,
}Expand description
Executor-local proxy launch inputs transported with one process start.
Unlike crate::ManagedNetworkSandboxContext, this describes how the executor should create
proxy listeners. The sandbox context is materialized only after those listeners are running.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.proxy: RemoteNetworkProxyConfigaudit_metadata: NetworkProxyAuditMetadataenvironment_id: Option<String>execution_id: Option<String>Implementations
Sourceimpl RemoteNetworkProxyLaunchConfig
impl RemoteNetworkProxyLaunchConfig
pub fn new(proxy: RemoteNetworkProxyConfig) -> Self
pub fn with_audit_metadata( self, audit_metadata: NetworkProxyAuditMetadata, ) -> Self
pub fn for_execution(self, environment_id: String, execution_id: String) -> Self